glados.utils module — GLaDOS 0.0.1.dev14 documentation

# glados.utils module

class `glados.utils.` `PyJSON`(d)

  Bases: `object`

  `from_dict`(d)
  `get`(key, default=None)
  `to_dict`()

`glados.utils.` `decode_kms`(ciphertext_blob: str) → str

  Decode a secret using the IAM role of the lambda function.

  Parameters

    ciphertext_blob – str ciphertext_blob to decode

  Returns

  str

    decoded text

`glados.utils.` `get_enc_var`(var_name: str)

  Get an encrypted ENV VAR

`glados.utils.` `get_var`(var_name: str)

  Get an ENV VAR

`glados.utils.` `read_config`(config_file: str)